@@ -1,23 +1,30 @@
-#' Keep strings matching a pattern.
+#' Keep strings matching a pattern, or find positions.
 #'
-#' This is a convenient wrapper around \code{x[str_detect(x, pattern)]}.
-#' Vectorised over \code{string} and \code{pattern}
+#' `str_subset()` is a wrapper around `x[str_detect(x, pattern)]`,
+#' and is equivalent to `grep(pattern, x, value = TRUE)`.
+#' `str_which()` is a wrapper around `which(str_detect(x, pattern))`,
+#' and is equivalent to `grep(pattern, x)`.
+#'
+#' Vectorised over `string` and `pattern`
 #'
 #' @inheritParams str_detect
 #' @return A character vector.
-#' @seealso \code{\link{grep}} with argument \code{value = TRUE},
-#'    \code{\link[stringi]{stri_subset}} for the underlying implementation.
+#' @seealso [grep()] with argument `value = TRUE`,
+#'    [stringi::stri_subset()] for the underlying implementation.
 #' @export
 #' @examples
 #' fruit <- c("apple", "banana", "pear", "pinapple")
 #' str_subset(fruit, "a")
+#' str_which(fruit, "a")
+#'
 #' str_subset(fruit, "^a")
 #' str_subset(fruit, "a$")
 #' str_subset(fruit, "b")
 #' str_subset(fruit, "[aeiou]")
 #'
-#' # Missings are silently dropped
+#' # Missings never match
 #' str_subset(c("a", NA, "b"), ".")
+#' str_which(c("a", NA, "b"), ".")
 str_subset <- function(string, pattern) {
   switch(type(pattern),
     empty = ,
@@ -27,3 +34,9 @@ str_subset <- function(string, pattern) {
     regex = stri_subset_regex(string, pattern, omit_na = TRUE, opts_regex = opts(pattern))
   )
 }
+
+#' @export
+#' @rdname str_subset
+str_which <- function(string, pattern) {
+  which(str_detect(string, pattern))
+}
